Web   ·   Wiki   ·   Activities   ·   Blog   ·   Lists   ·   Chat   ·   Meeting   ·   Bugs   ·   Git   ·   Translate   ·   Archive   ·   People   ·   Donate
summaryrefslogtreecommitdiffstats
path: root/recorded.py
diff options
context:
space:
mode:
authorerikb <erikb@574bc980-5f2d-0410-acbc-c8f9f0eb14e0>2007-09-05 01:15:58 (GMT)
committer erikb <erikb@574bc980-5f2d-0410-acbc-c8f9f0eb14e0>2007-09-05 01:15:58 (GMT)
commit5abf3a597f9807173ef13b78e7d9b8c4c842d0af (patch)
treebde6094e1a1463d6e2e6ebcd639c2bb970ed803e /recorded.py
parent59f4171e3ddb3af529a88aaeff9314053a107432 (diff)
more serialization bugs
git-svn-id: http://mediamods.com/public-svn/camera-activity/Record.activity@429 574bc980-5f2d-0410-acbc-c8f9f0eb14e0
Diffstat (limited to 'recorded.py')
-rw-r--r--recorded.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/recorded.py b/recorded.py
index 45c3968..fe470bd 100644
--- a/recorded.py
+++ b/recorded.py
@@ -56,7 +56,7 @@ class Recorded:
self.downloadedFromBuddy = False
#for flagging when you are being saved to the datastore for the first time...
#and just because you have an id, doesn't mean you're
self.saved = False
@@ -139,7 +139,7 @@ class Recorded:
def getAudioImagePixbuf( self ):
audioPixbuf = None
- if (self.datastoreId == None):
+ if ( (self.datastoreId==None) and (not self.saved) ):
audioFilepath = self.getAudioImageFilepath()
if (audioFilepath != None):
audioPixbuf = gtk.gdk.pixbuf_new_from_file(audioFilepath)
@@ -56,7 +56,7 @@ class Recorded:
self.downloadedFromBuddy = False
#for flagging when you are being saved to the datastore for the first time...
- #and just because you have an id, doesn't mean you're
+ #and just because you have an id, doesn't mean you're saved
self.saved = False